<!-- 
Confirm page for HHHL actions: cryptographic erase/export log.  The associated web plugin is the ConfirmHHHLActionWebPlugin. 
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<!-- Include some common templates created by SS -->
	<xsl:import href="Utils.xsl"/>
	<xsl:import href="hhhltbl.xsl"/>
	<xsl:template match="OMA">
		<DataArea exportdata="false" email="false" printable="false">
			<xsl:attribute name="validate">true</xsl:attribute>
			<xsl:attribute name="backpagedisplay"><xsl:value-of select="$strCancel"/></xsl:attribute>
			<xsl:attribute name="backpagetarget"><xsl:call-template name="ReturnPage"><xsl:with-param name="BackTo" select="/OMA/BackTo"/></xsl:call-template></xsl:attribute>
						
			<!-- Setting strings on XML page that varies depending on what the action is -->
			<xsl:variable name="warningtitle">		
			  <xsl:if test="/OMA/Action = 2097152 and //BusProtocol = '9'">
				<xsl:value-of select="$strCryptographicEraseASecureDiskWarningTitlePCIeSSD"/>
			  </xsl:if>				
			</xsl:variable>

			<xsl:variable name="areyousure">
				<xsl:if test="/OMA/Action = 2097152 and //BusProtocol= '9'" >
					<xsl:value-of select="$strRUSureCryptographicEraseASecureDiskPCIeSSD"/>
				</xsl:if>					
			</xsl:variable>
			
			<xsl:variable name="strAction">
				<xsl:if test="/OMA/Action = 2097152 and //BusProtocol = '9'">
					<xsl:choose>
						<xsl:when test="(/OMA/NVMeAdapters/DCStorageObject/IsDeviceNVME and /OMA/NVMeAdapters/DCStorageObject/IsDeviceNVME = '1')">
							<xsl:value-of select="$strCryptographicErase"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$strFullInitialization"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
					
			</xsl:variable>
			
			<!-- End setting strings -->

			<xsl:attribute name="submit">./SubmitForm?plugin=com.dell.sm.webplugins.ADExecuteActionWebPlugin&amp;ControllerOID=<xsl:value-of select="/OMA/ControllerOID"/>&amp;ChannelOID=<xsl:value-of select="/OMA/ChannelOID"/>&amp;ADiskOID=<xsl:value-of select="/OMA/ADiskOID"/>&amp;Action=<xsl:value-of select="/OMA/Action"/>&amp;Force=false&amp;help=hhhlin&amp;CurrentUrl=<xsl:value-of select="/OMA/BackTo"/>&amp;BackTo=<xsl:value-of select="/OMA/BackTo"/></xsl:attribute>		
			<xsl:attribute name="submitdisplay"><xsl:value-of select="$strAction"/></xsl:attribute>


			<AlertMessage alert="true" status="3">
				<xsl:attribute name="display">
                <xsl:choose>
                    <xsl:when test="/OMA/Action = 2097152 and //BusProtocol = '9'">
                        <xsl:choose>
                            <xsl:when test="(/OMA/NVMeAdapters/DCStorageObject/IsDeviceMounted and /OMA/NVMeAdapters/DCStorageObject/IsDeviceMounted = '1')">
                                <xsl:value-of select="$strEraseASecureDiskWarningMountTitlePart1"/>
                                <xsl:value-of select="/OMA/NVMeAdapters/DCStorageObject/MountInfo"/>
                                <xsl:value-of select="$strEraseASecureDiskWarningMountTitlePart2"/>											
                            </xsl:when>
                            <xsl:when test="(/OMA/NVMeAdapters/DCStorageObject/IsDeviceMounted and /OMA/NVMeAdapters/DCStorageObject/IsDeviceMounted = '0')">
                                <xsl:choose>
                                    <xsl:when test="(/OMA/NVMeAdapters/DCStorageObject/IOInProgress and /OMA/NVMeAdapters/DCStorageObject/IOInProgress = '0')">
                                        <xsl:value-of select="$strCryptographicEraseHHHLSupportMessage3"/>									
                                    </xsl:when>
                                    <xsl:when test="(/OMA/NVMeAdapters/DCStorageObject/IOInProgress and /OMA/NVMeAdapters/DCStorageObject/IOInProgress = '1')">
                                        <xsl:value-of select="$strCryptographicEraseHHHLSupportMessage2"/>									
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="$strCryptographicEraseASecureDiskWarningTitlePCIeSSD"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$strCryptographicEraseASecureDiskWarningTitlePCIeSSD"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$strCryptographicEraseASecureDiskWarningTitlePCIeSSD"/>
                    </xsl:otherwise>
                </xsl:choose>
                </xsl:attribute>
			</AlertMessage>


			<TableData name="Test1" display="Test2" columnspacing="true">
				<xsl:variable name="showtasks">false</xsl:variable>
				<Header>
					<xsl:call-template name="HHHLTableHeader">
						<xsl:with-param name="tasks">false</xsl:with-param>
						<xsl:with-param name="expanded">true</xsl:with-param>
					</xsl:call-template>
				</Header>
				<!-- should be only one array disk -->
				<xsl:for-each select="NVMeAdapters/DCStorageObject">
					<xsl:call-template name="HHHLTableRows">
					<xsl:with-param name="tasks">false</xsl:with-param>
					<xsl:with-param name="expanded">true</xsl:with-param>
					</xsl:call-template>
				</xsl:for-each>
			</TableData>

			<script language="javascript">
				function validate() 
				{
					// Validate doesn't need to validate any data, but just needs to prompt the user
					// to verify the want to continue with the delete.  confirm( ) will return true when
					// the user selects OK and false when the user selects CANCEL.				
					var warnmsg = "<xsl:value-of select="$areyousure"/>";
					
					var cfrm = confirm(warnmsg);
					if(cfrm)
					{
						
						disableButtons("submit","back" ,"");
						
					}
					
					return (cfrm);
				}				
			</script>
		
		</DataArea>
	</xsl:template>
</xsl:stylesheet>
